/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kmtp.Lister.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef LISTERADAPTOR_H
#define LISTERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "mtplister.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.kmtp.Lister
 */
class ListerAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kmtp.Lister")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kmtp.Lister\">\n"
"    <signal name=\"finished\"/>\n"
"    <signal name=\"entry\">\n"
"      <arg direction=\"out\" type=\"(uuustxs)\"/>\n"
"      <annotation value=\"KMTPFile\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </signal>\n"
"    <method name=\"run\"/>\n"
"    <method name=\"abort\"/>\n"
"  </interface>\n"
        "")
public:
    ListerAdaptor(MTPLister *parent);
    ~ListerAdaptor() override;

    inline MTPLister *parent() const
    { return static_cast<MTPLister *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void abort();
    void run();
Q_SIGNALS: // SIGNALS
    void entry(KMTPFile in0);
    void finished();
};

#endif
